@@ -87,7 +87,8 @@ class Test__characteristic_errors:
 
         # `Characteristic.get_unique_bias` runs during initialization
         # which prevents an exception from being raised..
-        langmuir.Characteristic(self.bias_2darr, self.current_2darr)
+        with pytest.warns(FutureWarning):
+            langmuir.Characteristic(self.bias_2darr, self.current_2darr)
 
     def test_infinite_I(self):
         r"""Test error upon an infinite current value"""
@@ -105,16 +106,20 @@ class Test__characteristic_errors:
         r"""Test errors upon unequal array lengths"""
 
         with pytest.raises(ValueError):
-            langmuir.Characteristic(self.bias_longarr, current_arr)
+            with pytest.warns(FutureWarning):
+                langmuir.Characteristic(self.bias_longarr, current_arr)
 
         with pytest.raises(ValueError):
-            langmuir.Characteristic(bias_arr, self.current_longarr)
+            with pytest.warns(FutureWarning):
+                langmuir.Characteristic(bias_arr, self.current_longarr)
 
     def test_addition(self):
         r"""Test addition of characteristic objects"""
 
-        a = langmuir.Characteristic(bias_arr, current_arr)
-        b = langmuir.Characteristic(bias_arr, self.current_arr2)
+        with pytest.warns(FutureWarning):
+            a = langmuir.Characteristic(bias_arr, current_arr)
+        with pytest.warns(FutureWarning):
+            b = langmuir.Characteristic(bias_arr, self.current_arr2)
 
         ab_sum = a + b
 
@@ -124,8 +129,10 @@ class Test__characteristic_errors:
     def test_subtraction(self):
         r"""Test addition of characteristic objects"""
 
-        a = langmuir.Characteristic(bias_arr, current_arr)
-        b = langmuir.Characteristic(bias_arr, self.current_arr2)
+        with pytest.warns(FutureWarning):
+            a = langmuir.Characteristic(bias_arr, current_arr)
+        with pytest.warns(FutureWarning):
+            b = langmuir.Characteristic(bias_arr, self.current_arr2)
 
         ab_sub = a - b
 
@@ -137,7 +144,8 @@ class Test__characteristic_errors:
 def characteristic():
     r"""Create a dummy characteristic with random values"""
 
-    return langmuir.Characteristic(bias_arr, current_arr)
+    with pytest.warns(FutureWarning):
+        return langmuir.Characteristic(bias_arr, current_arr)
 
 
 @pytest.fixture
@@ -145,8 +153,8 @@ def characteristic_simulated():
     r"""Create a simulated probe characteristic (provisional)"""
 
     T_e_sim = 1 * u.eV
-    n_e_sim = 1e18 * u.m ** -3
-    probe_area_sim = 1 * u.cm ** 2
+    n_e_sim = 1e18 * u.m**-3
+    probe_area_sim = 1 * u.cm**2
     I_es_sim = (
         n_e_sim * probe_area_sim * const.e * np.sqrt(T_e_sim / (2 * np.pi * const.m_e))
     )
@@ -167,8 +175,8 @@ def characteristic_simulated():
     current_simarr[current_simarr < I_es_sim] += (
         bias_simarr[current_simarr < I_es_sim] * 1e-4 * u.A / u.V
     )
-
-    return langmuir.Characteristic(bias_simarr, current_simarr)
+    with pytest.warns(FutureWarning):
+        return langmuir.Characteristic(bias_simarr, current_simarr)
 
 
 def shuffle_characteristic(characteristic):
@@ -204,36 +212,42 @@ class Test__Characteristic_inherited_methods:
     bias_4length_arr = np.array(np.random.rand(N - 1)) * u.V
     current_5length_arr = np.array(np.random.rand(N)) * u.A
 
-    bias_duplicates_arr = np.array((1, 2) * int(N / 2))
+    bias_duplicates_arr = np.array((1, 2) * int(N / 2)) * u.V
 
     def test_invalid_bias_dimensions(self):
         r"""Test error on non-1D bias array"""
         with pytest.raises(ValueError):
-            DryCharacteristic(self.bias_2darr, current_arr)
+            with pytest.warns(FutureWarning):
+                DryCharacteristic(self.bias_2darr, current_arr)
 
     def test_invalid_current_dimensions(self):
         r"""Test error on non-1d current array"""
         with pytest.raises(ValueError):
-            DryCharacteristic(bias_arr, self.current_2darr)
+            with pytest.warns(FutureWarning):
+                DryCharacteristic(bias_arr, self.current_2darr)
 
     def test_bias_and_current_length_mismatch(self):
         r"""Test error on non-1d bias and current arrays"""
 
         with pytest.raises(ValueError):
-            DryCharacteristic(self.bias_4length_arr, self.current_5length_arr)
+            with pytest.warns(FutureWarning):
+                DryCharacteristic(self.bias_4length_arr, self.current_5length_arr)
 
     def test_duplicate_bias_values(self):
         r"""Test error on bias array containing duplicate values"""
 
         with pytest.raises(ValueError):
-            DryCharacteristic(self.bias_duplicates_arr, current_arr)
+            with pytest.warns(FutureWarning):
+                DryCharacteristic(self.bias_duplicates_arr, current_arr)
 
     @staticmethod
     def test_inplace_unique_bias():
         r"""Test new Characteristic instance being returned"""
 
-        char = DryCharacteristic(bias_arr, current_arr)
-        new_char = char.get_unique_bias(inplace=False)
+        with pytest.warns(FutureWarning):
+            char = DryCharacteristic(bias_arr, current_arr)
+        with pytest.warns(FutureWarning):
+            new_char = char.get_unique_bias(inplace=False)
         assert char != new_char
         assert isinstance(new_char, langmuir.Characteristic)
 
@@ -257,42 +271,49 @@ class Test__swept_probe_analysis:
         r"""Test error upon NaN area"""
 
         with pytest.raises(ValueError):
-            langmuir.swept_probe_analysis(
-                characteristic, np.nan * u.cm ** 2, "Ar-40 1+"
-            )
+            with pytest.warns(FutureWarning):
+                langmuir.swept_probe_analysis(
+                    characteristic, np.nan * u.cm**2, "Ar-40 1+"
+                )
 
     @staticmethod
     def test_unit_conversion_error():
         r"""Test error upon incorrect probe area unit"""
 
         with pytest.raises(u.UnitTypeError):
-            langmuir.swept_probe_analysis(characteristic, 1 * u.cm, "Ar-40 1+")
+            with pytest.warns(FutureWarning):
+                langmuir.swept_probe_analysis(characteristic, 1 * u.cm, "Ar-40 1+")
 
     @staticmethod
     def test_negative_area():
         r"""Test error upon negative probe area"""
 
         with pytest.raises(ValueError):
-            langmuir.swept_probe_analysis(characteristic, -1 * u.cm ** 2, "Ar-40 1+")
+            with pytest.warns(FutureWarning):
+                langmuir.swept_probe_analysis(
+                    characteristic, -1 * u.cm**2, "Ar-40 1+"
+                )
 
     @staticmethod
     @pytest.mark.parametrize("bimaxwellian", [True, False])
     def test_ordering_invariance(bimaxwellian, characteristic_simulated):
         r"""Test invariance to ordering of the bias and current values"""
 
-        sim_result = langmuir.swept_probe_analysis(
-            characteristic_simulated,
-            1 * u.cm ** 2,
-            "Ar-40 1+",
-            bimaxwellian=bimaxwellian,
-        )
+        with pytest.warns(FutureWarning):
+            sim_result = langmuir.swept_probe_analysis(
+                characteristic_simulated,
+                1 * u.cm**2,
+                "Ar-40 1+",
+                bimaxwellian=bimaxwellian,
+            )
 
-        sim_result_shuffled = langmuir.swept_probe_analysis(
-            shuffle_characteristic(characteristic_simulated),
-            1 * u.cm ** 2,
-            "Ar-40 1+",
-            bimaxwellian=bimaxwellian,
-        )
+        with pytest.warns(FutureWarning):
+            sim_result_shuffled = langmuir.swept_probe_analysis(
+                shuffle_characteristic(characteristic_simulated),
+                1 * u.cm**2,
+                "Ar-40 1+",
+                bimaxwellian=bimaxwellian,
+            )
 
         errStr = "Analysis should be invariant to the ordering of the input data."
         for key in sim_result:
@@ -302,24 +323,30 @@ class Test__swept_probe_analysis:
 def test_get_floating_potential_with_return_arg(characteristic):
     r"""Test floating potential and the return argument"""
 
-    potential, arg = langmuir.get_floating_potential(characteristic, return_arg=True)
+    with pytest.warns(FutureWarning):
+        potential, arg = langmuir.get_floating_potential(
+            characteristic, return_arg=True
+        )
     assert np.allclose((potential.to(u.V).value, arg), (0.12203823, 5))
 
 
 def test_get_ion_density_OML_without_return_fit(characteristic):
     r"""Test ion density without returning the fit value"""
 
-    density = langmuir.get_ion_density_OML(
-        characteristic, 5000000 * u.m ** 2, "p+", return_fit=False
-    )
+    with pytest.warns(FutureWarning):
+        density = langmuir.get_ion_density_OML(
+            characteristic, 5000000 * u.m**2, "p+", return_fit=False
+        )
     assert np.isclose(density.value, 385344135.12064785)
 
 
 def test_get_EEDF():
     """Test the obtained EEDF"""
 
-    char = langmuir.Characteristic(bias_arr[:17], current_arr[:17])
-    energy, probability = langmuir.get_EEDF(char, visualize=False)
+    with pytest.warns(FutureWarning):
+        char = langmuir.Characteristic(bias_arr[:17], current_arr[:17])
+    with pytest.warns(FutureWarning):
+        energy, probability = langmuir.get_EEDF(char, visualize=False)
 
     expect_energy = (0.14118696, 0.05293109, 0.00709731)
     expect_probability = (8.64838751, 8.05295503, 3.42348436)
